%global debug_package %{nil}

Name:           docker-compose
Version:        1.9.0
Release:        5%{?dist}
Summary:        Multi-container orchestration for Docker

License:        ASL 2.0
URL:            https://www.docker.com/
Source0:        https://files.pythonhosted.org/packages/source/d/%{name}/%{name}-%{version}.tar.gz

# Remove dependency version constraints not relevant in Fedora/EPEL
Patch0:         relax-requirements.patch

# docker-compose is compatible with fig and is a simple rename.
# Currently it only prints deprecation warnings for changed functionality.
Provides:       fig = %{version}-%{release}
# Last fig EVR was 1.0.1-2
Obsoletes:      fig <= 1.0.1-3

BuildRequires:  python2-devel
BuildRequires:  python-setuptools 
BuildRequires:  python-docker-py
BuildRequires:  python-websocket-client
BuildRequires:  python-texttable
BuildRequires:  python-requests
BuildRequires:  PyYAML
BuildRequires:  python-docopt

Requires:       python-setuptools
# Version required due to upstream requirement; see BZ#1457376
Requires:       python-docker-py >= 1.10.6-1
# Version required due to upstream requirement; see BZ#1300106
Requires:       python-dockerpty >= 0.4.1-1
Requires:       python-texttable
Requires:       python-docopt
Requires:       python-requests
Requires:       python-websocket-client
Requires:       python-six
Requires:       python-jsonschema
Requires:       python-enum34
Requires:       PyYAML
Requires:       python-cached_property
Requires:       python-backports-ssl_match_hostname
Requires:       python2-backports-functools_lru_cache

BuildArch:      noarch

%description
Compose is a tool for defining and running multi-container Docker
applications. With Compose, you use a Compose file to configure your
application's services. Then, using a single command, you create and
start all the services from your configuration.

Compose is great for development, testing, and staging environments,
as well as CI workflows.

Using Compose is basically a three-step process.

1. Define your app's environment with a Dockerfile so it can be
   reproduced anywhere.
2. Define the services that make up your app in docker-compose.yml so
   they can be run together in an isolated environment:
3. Lastly, run docker-compose up and Compose will start and run your
   entire app.

%prep
%setup -q 

%patch0 -p1

# Upstream uses an underscore here
rm -r docker_compose.egg-info

%build
%{__python2} setup.py build

%install
%{__python2} setup.py install -O1 --skip-build --root $RPM_BUILD_ROOT

%files
%doc CHANGES.md CONTRIBUTING.md README.rst SWARM.md
%license LICENSE
%{_bindir}/%{name}
# Upstream uses an underscore here
%{python2_sitelib}/docker_compose*
%{python2_sitelib}/compose*

%changelog
* Tue Jun 06 2017 Carl George <carl.george@rackspace.com> - 1.9.0-5
- Relax minimum requirement of python-requests

* Wed May 31 2017 Michael Hampton <error@ioerror.us> - 1.9.0-4
- Update python-docker-py minimum version; fixes BZ#1457376

* Sun May 21 2017 Michael Hampton <error@ioerror.us> - 1.9.0-3
- Remove requires upper bound from setup.py, fixes BZ#1452999

* Sat Nov 19 2016 Michael Hampton <error@ioerror.us> - 1.9.0-2
- Add new upstream dependency python-backports-ssl_match_hostname

* Sat Nov 19 2016 Michael Hampton <error@ioerror.us> - 1.9.0-1
- Update to upstream 1.9.0
- Add new upstream dependency python2-backports-functools_lru_cache

* Fri Sep 23 2016 Michael Hampton <error@ioerror.us> - 1.8.1-1
- Update to upstream 1.8.1

* Thu Jul 28 2016 Michael Hampton <error@ioerror.us> - 1.8.0-1
- Update to upstream 1.8.0

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu May 05 2016 Michael Hampton <error@ioerror.us> - 1.7.1-1
- Update to upstream 1.7.1
- Updated package description from upstream

* Thu Apr 14 2016 Michael Hampton <error@ioerror.us> - 1.7.0-1
- Update to upstream 1.7.0

* Fri Feb 05 2016 Michael Hampton <error@ioerror.us> - 1.6.0-1
- Update to upstream 1.6.0

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jan 12 2016 Michael Hampton <error@ioerror.us> - 1.5.2-4
- Added missing dependency python-enum34

* Mon Jan 11 2016 Michael Hampton <error@ioerror.us> - 1.5.2-3
- Added missing dependency python-jsonschema

* Wed Dec 30 2015 Michael Hampton <error@ioerror.us> - 1.5.2-2
- Updated locations of docs

* Wed Dec 30 2015 Michael Hampton <error@ioerror.us> - 1.5.2-1
- Update to upstream 1.5.2

* Wed Sep 23 2015 Michael Hampton <error@ioerror.us> - 1.4.2-1
- Fixes a regression in the 1.4.1 release that would cause
  docker-compose up without the -d option to exit immediately.

* Wed Sep 16 2015 Michael Hampton <error@ioerror.us> - 1.4.1-1
- Update to upstream 1.4.1

* Wed Aug 12 2015 Michael Hampton <error@ioerror.us> - 1.4.0-1
- Update to upstream 1.4.0
- Update Summary to match upstream summary

* Sat May 16 2015 Michael Hampton <error@ioerror.us> - 1.2.0-3
- Update Obsoletes EVR per packaging guidelines BZ#1213111

* Sun Apr 19 2015 Michael Hampton <error@ioerror.us> - 1.2.0-2
- Update location of LICENSE file

* Sat Apr 18 2015 Michael Hampton <error@ioerror.us> - 1.2.0-1
- Update to 1.2.0
- Added new doc SWARM.md
- Removed docker package requires as it is not required to build or run the
  package, only to run tests, which we can't do anyway
- Removed commented code relating to running tests, which we can't do anyway
- Made package noarch as docker-io is no longer required

* Mon Mar 23 2015 Michael Hampton <error@ioerror.us> - 1.1.0-1
- Update to 1.1.0 including upstream name change
- Requires python-dockerpty
- Requires python-docker-py >= 0.7.1-3 BZ#1197300

* Tue Mar 17 2015 Matej Stuchlik <mstuchli@redhat.com> - 1.0.1-2
- Completely remove version specs from setup.py

* Tue Mar 17 2015 Matej Stuchlik <mstuchli@redhat.com> - 1.0.1-1
- Update to 1.0.1

* Wed Dec 03 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-5
- Remove upper bound from setup.py requires

* Wed Nov 12 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-4
- Add python-setuptools to requires

* Thu Oct 23 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-3
- Relax strict version requirements on websocket-client (#1155510)

* Tue Oct 21 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-2
- Update Requires

* Tue Oct 21 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-1
- Update to 1.0.0
- Droped the two patches

* Tue Oct 21 2014 Matej Stuchlik <mstuchli@redhat.com> - 0.5.2-2
- Explicitly disable debuginfo subpackage (#1154780)
- Add python-docker-py to Requires (#1154874)

* Thu Oct 09 2014 Matej Stuchlik <mstuchli@redhat.com> - 0.5.2-1
- Initial spec based on rhbz#1129889
